@@ -30,7 +30,8 @@
  *
  * Create a new PangoGlyphString.
  *
- * Returns the new PangoGlyphString
+ * Return value: the newly allocated #PangoGlyphString, which
+ *               should be freed with pango_glyph_string_free().
  */
 PangoGlyphString *
 pango_glyph_string_new (void)
@@ -66,7 +67,7 @@ pango_glyph_string_set_size (PangoGlyphString *string, gint new_len)
       
       if (string->space < 0)
         {
-	  g_critical ("glyph string length overflows maximum integer size, truncated");
+	  g_warning ("glyph string length overflows maximum integer size, truncated");
 	  new_len = string->space = G_MAXINT - 8;
 	}
     }
@@ -95,7 +96,8 @@ pango_glyph_string_get_type (void)
  *
  *  Copy a glyph string and associated storage.
  *
- * Returns the copied PangoGlyphString
+ * Return value: the newly allocated #PangoGlyphString, which
+ *               should be freed with pango_glyph_string_free().
  */
 PangoGlyphString *
 pango_glyph_string_copy (PangoGlyphString *string)
@@ -116,7 +118,7 @@ pango_glyph_string_copy (PangoGlyphString *string)
  * pango_glyph_string_free:
  * @string:    a PangoGlyphString.
  *
- *  Free a glyph string and associated storage.
+ * Free a glyph string and associated storage.
  */
 void
 pango_glyph_string_free (PangoGlyphString *string)
