@@ -97,7 +97,10 @@ G_CONST_RETURN char *pango_language_get_sample_string (PangoLanguage *language);
 /* Unicode characters that are zero-width and should not be rendered
  * normally.
  */
-G_GNUC_CONST gboolean pango_is_zero_width (gunichar ch);
+gboolean pango_is_zero_width (gunichar ch) G_GNUC_CONST;
+
+/* String interning for static strings */
+#define I_(string) g_intern_static_string (string)
 
 G_END_DECLS
 
